@@ -642,10 +642,15 @@ sub wei
             unless ( !keys %{ $res_ref } and ( $ordist > 0 ) and ( $ordist ne "" ) ) ######## IMPROVE THIS SO AS TO ALLOW VERY DIFFERENT NUMBERS OF LEVELS FOR EACH FACTOR
             { #say $tee " SO I AM IN. ";
 
-              my @sorteds = sort { $b <=> $a } @{ $bank{$trio}{strengths} };
-              my $benchmark = $sorteds[$nfilter-1];
+              my @sorteds;
+              my $benchmark;
+              if ( $nfilter )
+              {
+                @sorteds = sort { $b <=> $a } @{ $bank{$trio}{strengths} };
+                $benchmark = $sorteds[$nfilter-1];
+              }
 
-              if ( ( ($nfilter) and ( $strength > $benchmark ) ) or ( not( $nfilter ) ) )
+              if ( ( $strength > $benchmark ) or ( not( $nfilter ) ) )
               {
 
                 my $count = 0;
